window.Gleam.initSearch([{"doc":"glemini","title":"glemini","content":"# glemini\n\n[![Package Version](https://img.shields.io/hexpm/v/glemini)](https://hex.pm/packages/glemini)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glemini/)\n\nA Gleam library for building [Gemini](https://geminiprotocol.net/) servers.\n\n## Usage\n\nAdd `glemini` to your project:\n```sh\ngleam add glemini\n```\n\nCreate self-signed server certificates:\n```sh\nopenssl req -x509 -nodes -newkey rsa:4096 -keyout certs/cert.key -out certs/cert.crt -sha256 -days 365\n```\n\nCreate the gemini server with a request handler:\n```gleam\nimport gleam/erlang/process\nimport gleam/io\nimport glemini.{\n  add_handler, add_ssl, gemtext_response, new_config, not_found_response, start,\n}\nimport glemini/gemtext.{heading1, text}\n\npub fn main() {\n  io.println(&quot;Starting server!&quot;)\n\n  let config =\n    new_config()\n    |&gt; add_ssl(certfile: &quot;certs/cert.crt&quot;, keyfile: &quot;certs/cert.key&quot;)\n    |&gt; add_handler(fn(request) {\n      case request.path {\n        &quot;/&quot; -&gt;\n          [\n            heading1(&quot;Welcome to Glemini!&quot;),\n            text(&quot;This is a simple gemini server library&quot;),\n          ]\n          |&gt; gemtext_response()\n        _ -&gt; not_found_response()\n      }\n    })\n\n  let assert Ok(_) = start(config)\n\n  io.println(&quot;Server running!&quot;)\n  process.sleep_forever()\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glemini&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glemini/gemtext","title":"Line","content":"pub opaque type Line\n Type representing gemtext lines.\n\nSynonyms:\nglemini/gemtext.Line\nglemini/gemtext Line","url":"glemini/gemtext.html#Line"},{"doc":"glemini/gemtext","title":"Lines","content":"pub type Lines =\n  List(Line)\n Type alias for a list of gemtext lines.\n\nSynonyms:\nglemini/gemtext.Lines\nglemini/gemtext Lines","url":"glemini/gemtext.html#Lines"},{"doc":"glemini/gemtext","title":"blank_line","content":"pub fn blank_line() -&gt; Line\n\nSynonyms:\nglemini/gemtext.blank_line\nglemini/gemtext blank_line","url":"glemini/gemtext.html#blank_line"},{"doc":"glemini/gemtext","title":"heading1","content":"pub fn heading1(text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.heading1\nglemini/gemtext heading1","url":"glemini/gemtext.html#heading1"},{"doc":"glemini/gemtext","title":"heading2","content":"pub fn heading2(text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.heading2\nglemini/gemtext heading2","url":"glemini/gemtext.html#heading2"},{"doc":"glemini/gemtext","title":"heading3","content":"pub fn heading3(text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.heading3\nglemini/gemtext heading3","url":"glemini/gemtext.html#heading3"},{"doc":"glemini/gemtext","title":"line_to_string","content":"pub fn line_to_string(line: Line) -&gt; String\n Convert a gemtext line into a string.\nSynonyms:\nglemini/gemtext.line_to_string\nglemini/gemtext line_to_string","url":"glemini/gemtext.html#line_to_string"},{"doc":"glemini/gemtext","title":"lines_to_string","content":"pub fn lines_to_string(lines: List(Line)) -&gt; String\n Convert a list of gemtext lines into a string.\nSynonyms:\nglemini/gemtext.lines_to_string\nglemini/gemtext lines_to_string","url":"glemini/gemtext.html#lines_to_string"},{"doc":"glemini/gemtext","title":"link","content":"pub fn link(uri: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.link\nglemini/gemtext link","url":"glemini/gemtext.html#link"},{"doc":"glemini/gemtext","title":"link_with_caption","content":"pub fn link_with_caption(uri: String, text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.link_with_caption\nglemini/gemtext link_with_caption","url":"glemini/gemtext.html#link_with_caption"},{"doc":"glemini/gemtext","title":"list_item","content":"pub fn list_item(text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.list_item\nglemini/gemtext list_item","url":"glemini/gemtext.html#list_item"},{"doc":"glemini/gemtext","title":"preformatted","content":"pub fn preformatted(text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.preformatted\nglemini/gemtext preformatted","url":"glemini/gemtext.html#preformatted"},{"doc":"glemini/gemtext","title":"preformatted_with_caption","content":"pub fn preformatted_with_caption(\n  text: String,\n  caption: String,\n) -&gt; Line\n\nSynonyms:\nglemini/gemtext.preformatted_with_caption\nglemini/gemtext preformatted_with_caption","url":"glemini/gemtext.html#preformatted_with_caption"},{"doc":"glemini/gemtext","title":"qoute","content":"pub fn qoute(text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.qoute\nglemini/gemtext qoute","url":"glemini/gemtext.html#qoute"},{"doc":"glemini/gemtext","title":"text","content":"pub fn text(text: String) -&gt; Line\n\nSynonyms:\nglemini/gemtext.text\nglemini/gemtext text","url":"glemini/gemtext.html#text"},{"doc":"glemini/gemtext","title":"glemini/gemtext","content":" A helper module for generating gemtext.\n # Example:\n ```gleam\n [\n   heading1(&quot;Welcome to Glemini!&quot;),\n   text(&quot;This is a simple gemini server library&quot;),\n   link_with_caption(&quot;gemini://geminiprotocol.net&quot;, &quot;Gemini Website&quot;),\n ]\n |&gt; lines_to_string\n ```\n ## Results in:\n ```gemtext\n # Welcome to Glemini!\n This is a simple gemini server library\n =&gt; gemini://geminiprotocol.net Gemini Website\n ```","url":"glemini/gemtext.html"},{"doc":"glemini","title":"GleminiError","content":"pub opaque type GleminiError\n\n\nSynonyms:\nglemini.GleminiError\nglemini GleminiError","url":"glemini.html#GleminiError"},{"doc":"glemini","title":"Request","content":"pub opaque type Request\n\n\nSynonyms:\nglemini.Request\nglemini Request","url":"glemini.html#Request"},{"doc":"glemini","title":"Response","content":"pub type Response {\n  SuccessResponse(status: Int, mimetype: String, body: String)\n  InputResponse(status: Int, prompt: String)\n  RedirectResponse(status: Int, uri: String)\n  ErrorResponse(status: Int, message: Option(String))\n}\n\nSuccessResponse(status: Int, mimetype: String, body: String)\n\n\nInputResponse(status: Int, prompt: String)\n\n\nRedirectResponse(status: Int, uri: String)\n\n\nErrorResponse(status: Int, message: Option(String))\n\n\nSynonyms:\nglemini.Response\nglemini Response","url":"glemini.html#Response"},{"doc":"glemini","title":"ServerConfig","content":"pub type ServerConfig {\n  ServerConfig(\n    port: Int,\n    certfile: String,\n    keyfile: String,\n    request_handler: fn(Request) -&gt; Response,\n  )\n}\n Glemini server configuration.\nServerConfig(\n  port: Int,\n  certfile: String,\n  keyfile: String,\n  request_handler: fn(Request) -&gt; Response,\n)\n\n\nSynonyms:\nglemini.ServerConfig\nglemini ServerConfig","url":"glemini.html#ServerConfig"},{"doc":"glemini","title":"add_handler","content":"pub fn add_handler(\n  config: ServerConfig,\n  request_handler: fn(Request) -&gt; Response,\n) -&gt; ServerConfig\n Adds a request handler to the server configuration.\n The request handler is your main function where you&#39;ll do routing.\n # Example handler\n \n fn my_request_handler(req: Request) -&gt; Response {\n   case req.path {\n     &quot;/hello&quot; -&gt; gemtext_response([gemtext.heading1(&quot;Hello, world!&quot;)])\n     _ -&gt; not_found_response()\n   }\n }\n \nSynonyms:\nglemini.add_handler\nglemini add_handler","url":"glemini.html#add_handler"},{"doc":"glemini","title":"add_ssl","content":"pub fn add_ssl(\n  config: ServerConfig,\n  certfile certfile: String,\n  keyfile keyfile: String,\n) -&gt; ServerConfig\n Adds ssl configuration to the server configuration.\nSynonyms:\nglemini.add_ssl\nglemini add_ssl","url":"glemini.html#add_ssl"},{"doc":"glemini","title":"bad_request_response","content":"pub fn bad_request_response(message: String) -&gt; Response\n Creates a bad request response, status 59, with a given message.\nSynonyms:\nglemini.bad_request_response\nglemini bad_request_response","url":"glemini.html#bad_request_response"},{"doc":"glemini","title":"certificate_not_authorized_response","content":"pub fn certificate_not_authorized_response(\n  message: String,\n) -&gt; Response\n Creates a certificate not authorized response, status 61, with a given message.\nSynonyms:\nglemini.certificate_not_authorized_response\nglemini certificate_not_authorized_response","url":"glemini.html#certificate_not_authorized_response"},{"doc":"glemini","title":"certificate_not_valid_response","content":"pub fn certificate_not_valid_response(\n  message: String,\n) -&gt; Response\n Creates a certificate not valid response, status 62, with a given message.\nSynonyms:\nglemini.certificate_not_valid_response\nglemini certificate_not_valid_response","url":"glemini.html#certificate_not_valid_response"},{"doc":"glemini","title":"cgi_error_response","content":"pub fn cgi_error_response() -&gt; Response\n Creates a CGI error response, status 42.\nSynonyms:\nglemini.cgi_error_response\nglemini cgi_error_response","url":"glemini.html#cgi_error_response"},{"doc":"glemini","title":"client_certificate_required_response","content":"pub fn client_certificate_required_response(\n  message: String,\n) -&gt; Response\n Creates a client certificate required response, status 60, with a given message.\nSynonyms:\nglemini.client_certificate_required_response\nglemini client_certificate_required_response","url":"glemini.html#client_certificate_required_response"},{"doc":"glemini","title":"gemtext_response","content":"pub fn gemtext_response(lines: List(Line)) -&gt; Response\n Creates a success response, status 20, with a gemtext body created from a list of gemtext lines.\nSynonyms:\nglemini.gemtext_response\nglemini gemtext_response","url":"glemini.html#gemtext_response"},{"doc":"glemini","title":"gone_response","content":"pub fn gone_response() -&gt; Response\n Creates a gone response, status 52.\nSynonyms:\nglemini.gone_response\nglemini gone_response","url":"glemini.html#gone_response"},{"doc":"glemini","title":"input_response","content":"pub fn input_response(prompt: String) -&gt; Response\n Creates an input response, status 10, with a given prompt.\nSynonyms:\nglemini.input_response\nglemini input_response","url":"glemini.html#input_response"},{"doc":"glemini","title":"new_config","content":"pub fn new_config() -&gt; ServerConfig\n Creates a new server configuration with missing certificate and empty request handler.\nSynonyms:\nglemini.new_config\nglemini new_config","url":"glemini.html#new_config"},{"doc":"glemini","title":"not_found_response","content":"pub fn not_found_response() -&gt; Response\n Creates a not found response, status 51.\nSynonyms:\nglemini.not_found_response\nglemini not_found_response","url":"glemini.html#not_found_response"},{"doc":"glemini","title":"permanent_failure_response","content":"pub fn permanent_failure_response(message: String) -&gt; Response\n Creates a permanent failure response, status 50, with a given message.\nSynonyms:\nglemini.permanent_failure_response\nglemini permanent_failure_response","url":"glemini.html#permanent_failure_response"},{"doc":"glemini","title":"permanent_redirect_response","content":"pub fn permanent_redirect_response(uri: String) -&gt; Response\n Creates a permanent redirect response, status 31, with a given uri.\nSynonyms:\nglemini.permanent_redirect_response\nglemini permanent_redirect_response","url":"glemini.html#permanent_redirect_response"},{"doc":"glemini","title":"proxy_error_response","content":"pub fn proxy_error_response() -&gt; Response\n Creates a proxy error response, status 43.\nSynonyms:\nglemini.proxy_error_response\nglemini proxy_error_response","url":"glemini.html#proxy_error_response"},{"doc":"glemini","title":"proxy_request_refused_response","content":"pub fn proxy_request_refused_response() -&gt; Response\n Creates a proxy request refused response, status 53.\nSynonyms:\nglemini.proxy_request_refused_response\nglemini proxy_request_refused_response","url":"glemini.html#proxy_request_refused_response"},{"doc":"glemini","title":"sensitive_input_response","content":"pub fn sensitive_input_response(prompt: String) -&gt; Response\n Creates a sensitive input response, status 11, with a given prompt.\nSynonyms:\nglemini.sensitive_input_response\nglemini sensitive_input_response","url":"glemini.html#sensitive_input_response"},{"doc":"glemini","title":"server_unavailable_response","content":"pub fn server_unavailable_response() -&gt; Response\n Creates a server unavailable response, status 41.\nSynonyms:\nglemini.server_unavailable_response\nglemini server_unavailable_response","url":"glemini.html#server_unavailable_response"},{"doc":"glemini","title":"slow_down_response","content":"pub fn slow_down_response() -&gt; Response\n Creates a slow down response, status 44.\nSynonyms:\nglemini.slow_down_response\nglemini slow_down_response","url":"glemini.html#slow_down_response"},{"doc":"glemini","title":"start","content":"pub fn start(\n  config: ServerConfig,\n) -&gt; Result(Subject(Message), StartError)\n Starts the gemini server.\n Expects a `ServerConfig`\n # Example\n \n new_config()\n |&gt; add_ssl(certfile: &quot;certs/cert.crt&quot;, keyfile: &quot;certs/cert.key&quot;)\n |&gt; add_handler(fn(req) {\n   case req.path {\n     &quot;/hello&quot; -&gt; gemtext_response([gemtext.heading1(&quot;Welcome to Glemini!&quot;)])\n     _ -&gt; not_found_response()\n   }\n })\n |&gt; start\n \nSynonyms:\nglemini.start\nglemini start","url":"glemini.html#start"},{"doc":"glemini","title":"success_response","content":"pub fn success_response(\n  mimetype: String,\n  body: String,\n) -&gt; Response\n Creates a success response, status 20, with a given mimetype and body.\nSynonyms:\nglemini.success_response\nglemini success_response","url":"glemini.html#success_response"},{"doc":"glemini","title":"temporary_failure_response","content":"pub fn temporary_failure_response(message: String) -&gt; Response\n Creates a temporary failure response, status 40, with a given message.\nSynonyms:\nglemini.temporary_failure_response\nglemini temporary_failure_response","url":"glemini.html#temporary_failure_response"},{"doc":"glemini","title":"temporary_redirect_response","content":"pub fn temporary_redirect_response(uri: String) -&gt; Response\n Creates a temporary redirect response, status 30, with a given uri.\nSynonyms:\nglemini.temporary_redirect_response\nglemini temporary_redirect_response","url":"glemini.html#temporary_redirect_response"},{"doc":"glemini","title":"glemini","content":" Main Glemini module. Contains the server and response functions.\n # Example usage:\n ```gleam\n let config =\n   new_config()\n   |&gt; add_ssl(certfile: &quot;certs/cert.crt&quot;, keyfile: &quot;certs/cert.key&quot;)\n   |&gt; add_handler(fn(req) {\n     case req.path {\n       &quot;/&quot; -&gt; gemtext_response([gemtext.heading1(&quot;Welcome to Glemini!&quot;)])\n       _ -&gt; not_found_response()\n     }\n   })\n let assert Ok(_) = start(config)\n ```","url":"glemini.html"}]);